@@ -5,11 +5,12 @@ This module provides all the necessary data.
 import xmlrpc.client
 import shutil
 import csv
+import sys
 import os
 from subprocess import Popen, PIPE
 from dataclasses import dataclass
 
-__version__ = "0.2.7"
+__version__ = "0.2.8"
 
 
 
@@ -46,24 +47,48 @@ def get_python_installs():
     py_info_list = []
     csv_file = os.path.expanduser("~/.venvipy/py-installs")
 
+    if not os.path.exists(os.path.expanduser("~/.venvipy")):
+        os.mkdir(os.path.expanduser("~/.venvipy"))
+
     with open(csv_file, "w", newline="") as cf:
         fields = ["PYTHON_VERSION", "PYTHON_PATH"]
         writer = csv.DictWriter(
             cf, delimiter=",", quoting=csv.QUOTE_ALL, fieldnames=fields
         )
         writer.writeheader()
-
         for i, version in enumerate(versions):
             python_path = shutil.which(f"python{version}")
             if python_path is not None:
                 python_version = get_python_version(python_path)
                 py_info = PythonInfo(python_version, python_path)
                 py_info_list.append(py_info)
-
                 writer.writerow({
                     "PYTHON_VERSION": py_info.py_version,
                     "PYTHON_PATH": py_info.py_path
                 })
+    add_sys_python()
+
+
+def add_sys_python():
+    """
+    Add the system python if running VenviPy in a
+    virtual environment.
+    """
+    csv_file = os.path.expanduser("~/.venvipy/py-installs")
+    super_python = os.path.realpath(sys.executable)
+
+    if not os.path.isfile(csv_file):
+        get_python_installs()
+
+    with open(csv_file, "a", newline="") as cf:
+        fields = ["PYTHON_VERSION", "PYTHON_PATH"]
+        writer = csv.DictWriter(
+            cf, delimiter=",", quoting=csv.QUOTE_ALL, fieldnames=fields
+        )
+        writer.writerow({
+            "PYTHON_VERSION": get_python_version(super_python),
+            "PYTHON_PATH": super_python
+        })
 
 
 #]===========================================================================[#
@@ -145,9 +170,6 @@ def get_pyvenv_cfg(cfg_file, line):
     with open(cfg_file, "r") as f:
         lines = f.readlines()
 
-    if line == 0:
-        python_path = lines[0][7:]  # e.g. /usr/local/bin
-        return python_path.strip()
     if line == 1:
         system_site_packages = lines[1][31:]  # true | false
         if "true" in system_site_packages:
@@ -166,12 +188,14 @@ def get_active_dir_str():
     """
     active_file = os.path.expanduser("~/.venvipy/active")
 
+    if not os.path.exists(os.path.expanduser("~/.venvipy")):
+        os.mkdir(os.path.expanduser("~/.venvipy"))
+
     if os.path.exists(active_file):
         with open(active_file, "r") as f:
             active_dir = f.read()
             return active_dir
     else:
-        os.mkdir(os.path.expanduser("~/.venvipy"))
         with open(active_file, "w+") as f:
             active_dir = f.write("")
             return active_dir
