@@ -71,7 +71,7 @@ class VenvWizard(QWizard):
     Wizard for creating and setting up a virtual environment.
     """
     refresh = pyqtSignal()
-    update_table = pyqtSignal(str)
+    update_table = pyqtSignal()
 
     def __init__(self):
         super().__init__()
@@ -317,15 +317,13 @@ class BasicSettings(QWizardPage):
 
     def pop_combo_box(self):
         """
-        Add the found Python versions to combo box
+        Add the selected Python version to combo box.
         """
         csv_file = os.path.expanduser("~/.venvipy/py-installs")
 
         if os.path.isfile(csv_file):
-            info = []
             with open(csv_file, newline="") as cf:
                 reader = csv.DictReader(cf, delimiter=",")
-
                 for info in reader:
                     self.interpreter_combo_box.addItem(
                         f'{info["PYTHON_VERSION"]}  ->  {info["PYTHON_PATH"]}',
@@ -360,12 +358,12 @@ class BasicSettings(QWizardPage):
                     "PYTHON_VERSION": custom_version,
                     "PYTHON_PATH": bin_file
                 })
-                self.interpreter_combo_box.addItem(
-                    f"{custom_version}  ->  {bin_file}", bin_file
-                )
-        # transmit bin_file to pop_interpreter_table() in MainWindow
-        self.wizard().update_table.emit(bin_file)
-        return bin_file
+            # clear combo box content and call pop_combo_box()
+            self.interpreter_combo_box.clear()
+            self.interpreter_combo_box.addItem("---")
+            self.pop_combo_box()
+            # also call pop_interpreter_table() method in venvi.MainWindow
+            self.wizard().update_table.emit()
 
 
     def select_dir(self):
